(* Warning! ocsigen_config.ml is generated automatically from ocsigen_config.ml.in!
   Do not modify it manually *)
(* Ocsigen
 * Copyright (C) 2005 Vincent Balat
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, with linking exception;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *)

open Ocsigen_lib

exception Config_file_error of string

(* General config *)
let config_file = ref "/usr/pkg/share/examples/ocsigen/ocsigenserver.conf"
let verbose = ref false
let silent = ref false
let daemon = ref false
let veryverbose = ref false
let debug = ref false
let version_number = (**)"2.9"(**)
let pidfile = ref None
let server_name = "Ocsigen"
let full_server_name = server_name^"/"^version_number
let is_native = Dynlink.is_native
let native_ext = if is_native then ".opt" else ""

let builtin_packages =
  List.fold_left (fun a s -> String.Set.add s a) String.Set.empty ["unix";"bigarray";"bytes";"result";"seq";"lwt";"mmap";"ocplib-endian.bigstring";"threads";"lwt.unix";"ssl";"lwt_ssl";"lwt_log.core";"lwt_log";"astring";"uchar";"fmt";"domain-name";"macaddr";"ipaddr";"str";"netsys";"netstring";"pcre";"netstring-pcre";"findlib.internal";"findlib";"zarith";"cryptokit";"re";"uutf";"tyxml.functor";"tyxml";"xml-light";"dynlink"; "ocsigenserver.commandline"; "ocsigenserver.polytables"; "ocsigenserver.cookies"; "ocsigenserver.baselib"; "ocsigenserver.http"; "ocsigenserver"; ]

(* Server config: *)
let (uploaddir : string option ref) = ref None
let logdir = ref (Some ("/var/log/ocsigen"))
let syslog_facility = ref None
let default_user = ref "www"
let default_group = ref "www"
let minthreads = ref 10
let maxthreads = ref 30
let max_number_of_connections = ref 350
let mimefile = ref "/usr/pkg/share/examples/ocsigen/mime.types"
let silent_client_timeout = ref 30 (* without speaking during sending frame *)
let silent_server_timeout = ref 30 (* without speaking during sending frame *)
(*let keepalive_timeout = ref 30
let keepopen_timeout = ref 300 (* for ocsigen as client *) *)
let netbuffersize = ref 8192
let filebuffersize = ref 8192
let maxrequestbodysize = ref (Some (Int64.of_int 8000000))
let maxrequestbodysizeinmemory = ref 8192
let maxuploadfilesize = ref (Some (Int64.of_int 2000000))
let defaultcharset = ref (None : string option)
let datadir = ref "/var/lib/ocsigen"
let bindir = ref "/usr/pkg/bin"
let extdir = ref "/usr/pkg/lib/ocaml/site-lib/ocsigenserver/extensions"
let user = ref (Some !default_user)
let group = ref (Some !default_group)
let command_pipe = ref "/var/run/ocsigen_command"
let debugmode = ref false
let disablepartialrequests = ref false
let usedefaulthostname = ref false
let respectpipeline = ref false
let default_port = ref 80
let default_sslport = ref 443
let maxretries = ref 10
let shutdowntimeout = ref (Some 10.)

let set_uploaddir u = uploaddir := u
let set_logdir s = logdir := Some s
let set_syslog_facility f = syslog_facility := f; logdir := None
let set_configfile s = config_file := s
let set_pidfile s = pidfile := Some s
let set_mimefile s = mimefile := s
let () = Lwt_log.add_rule "ocsigen:*" Lwt_log.Warning (* without --verbose *)
let set_verbose () =
  verbose := true;
  Lwt_log.add_rule "ocsigen:*" Lwt_log.Notice
let set_silent () = silent := true
let set_daemon () = set_silent (); daemon := true
let set_veryverbose () =
  verbose := true;
  veryverbose := true;
  Lwt_log.add_rule "ocsigen:*" Lwt_log.Info
let set_debug () =
  verbose := true;
  veryverbose := true;
  debug := true;
  Lwt_log.add_rule "ocsigen:*" Lwt_log.Debug

let set_minthreads i = minthreads := i
let set_maxthreads i = maxthreads := i
let set_max_number_of_threads_queued =
  Lwt_preemptive.set_max_number_of_threads_queued
let set_max_number_of_connections i = max_number_of_connections := i
let set_client_timeout i = silent_client_timeout := i
let set_server_timeout i = silent_server_timeout := i
(* let set_keepalive_timeout i = keepalive_timeout := i
let set_keepopen_timeout i = keepopen_timeout := i *)
let set_netbuffersize i = netbuffersize := i
let set_filebuffersize i = filebuffersize := i
let set_maxuploadfilesize i = maxuploadfilesize := i
let set_maxrequestbodysize i = maxrequestbodysize := i
let set_maxrequestbodysizeinmemory i = maxrequestbodysizeinmemory := i
let set_default_charset o = defaultcharset := o
let set_datadir o = datadir := o
let set_bindir o = bindir := o
let set_extdir o = extdir := o
let set_user o = user := o
let set_group o = group := o
let set_command_pipe s = command_pipe := s
let set_debugmode s = debugmode := s
let set_disablepartialrequests s = disablepartialrequests := s
let set_usedefaulthostname s = usedefaulthostname := s
let set_respect_pipeline () = respectpipeline := true
let set_default_port p = default_port := p
let set_default_sslport p = default_sslport := p
let set_maxretries i = maxretries := i
let set_shutdown_timeout s = shutdowntimeout := s

let get_uploaddir () = !uploaddir
let get_logdir () =
  match !logdir with
  | Some s -> s
  | None -> raise (
    Config_file_error ("Log directory requested, but not set"));;
let get_syslog_facility () = !syslog_facility
let get_config_file () = !config_file
let get_pidfile () = !pidfile
let get_mimefile () = !mimefile
let get_verbose () = !verbose
let get_silent () = !silent
let get_daemon () = !daemon
let get_veryverbose () = !veryverbose
let get_debug () = !debug
let get_default_user () = !default_user
let get_default_group () = !default_group
let get_minthreads () = !minthreads
let get_maxthreads () = !maxthreads
let get_max_number_of_threads_queued =
  Lwt_preemptive.get_max_number_of_threads_queued
let get_max_number_of_connections () = !max_number_of_connections
let get_client_timeout () = !silent_client_timeout
let get_server_timeout () = !silent_server_timeout
(*let get_keepalive_timeout () = !keepalive_timeout
let get_keepopen_timeout () = !keepopen_timeout *)
let get_netbuffersize () = !netbuffersize
let get_filebuffersize () = !filebuffersize
let get_maxuploadfilesize () = !maxuploadfilesize
let get_maxrequestbodysize () = !maxrequestbodysize
let get_maxrequestbodysizeinmemory () = !maxrequestbodysizeinmemory
let get_default_charset () = !defaultcharset
let get_datadir () = !datadir
let get_bindir () = !bindir
let get_extdir () = !extdir
let get_user () = !user
let get_group () = !group
let get_command_pipe () = !command_pipe
let get_debugmode () = !debugmode
let get_disablepartialrequests () = !disablepartialrequests
let get_usedefaulthostname () = !usedefaulthostname
let get_respect_pipeline () = !respectpipeline
let get_default_port () = !default_port
let get_default_sslport () = !default_sslport
let get_maxretries () = !maxretries
let get_shutdown_timeout () = !shutdowntimeout

let display_version () =
  print_string version_number;
  print_newline ();
  exit 0

let init_preempt = Lwt_preemptive.init
